@@ -1,6 +1,6 @@
 package Beam::Wire;
 # ABSTRACT: Lightweight Dependency Injection Container
-$Beam::Wire::VERSION = '1.011';
+$Beam::Wire::VERSION = '1.012';
 use strict;
 use warnings;
 
@@ -271,11 +271,12 @@ sub create_service {
 
         for my $listener ( @listeners ) {
             my ( $event, $conf ) = @$listener;
-            # XXX: Make $args prepend arguments to the listener
-            # XXX: Make $args also resolve refs
-            my $method = delete $conf->{ $meta{method} };
+            if ( $conf->{ $meta{method} } && !$conf->{ $meta{sub} } ) {
+                _deprecated( 'warning: (deprecated) "$method" in event handlers is now "$sub" in service "' . $name . '"' );
+            }
+            my $sub_name = delete $conf->{ $meta{sub} } || delete $conf->{ $meta{method} };
             my ( $listen_svc ) = $self->find_refs( $conf );
-            $service->on( $event => sub { $listen_svc->$method( @_ ) } );
+            $service->on( $event => sub { $listen_svc->$sub_name( @_ ) } );
         }
     }
 
@@ -357,6 +358,7 @@ sub get_meta_names {
         args    => "${prefix}args",
         class   => "${prefix}class",
         extends => "${prefix}extends",
+        sub     => "${prefix}sub",
     );
     return wantarray ? %meta : \%meta;
 }
@@ -412,6 +414,13 @@ sub BUILD {
     return;
 }
 
+my %deprecated_warnings;
+sub _deprecated {
+    my ( $warning ) = @_;
+    return if $deprecated_warnings{ $warning };
+    warn $deprecated_warnings{ $warning } = $warning . "\n";
+}
+
 # Load a config file
 sub _load_config {
     my ( $self, $path ) = @_;
@@ -424,7 +433,7 @@ sub _load_config {
 
 
 package Beam::Wire::Exception;
-$Beam::Wire::Exception::VERSION = '1.011';
+$Beam::Wire::Exception::VERSION = '1.012';
 use Moo;
 with 'Throwable';
 use Types::Standard qw( :all );
@@ -437,7 +446,7 @@ has error => (
 
 
 package Beam::Wire::Exception::Constructor;
-$Beam::Wire::Exception::Constructor::VERSION = '1.011';
+$Beam::Wire::Exception::Constructor::VERSION = '1.012';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -450,7 +459,7 @@ has attr => (
 
 
 package Beam::Wire::Exception::Service;
-$Beam::Wire::Exception::Service::VERSION = '1.011';
+$Beam::Wire::Exception::Service::VERSION = '1.012';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -468,7 +477,7 @@ has file => (
 
 
 package Beam::Wire::Exception::NotFound;
-$Beam::Wire::Exception::NotFound::VERSION = '1.011';
+$Beam::Wire::Exception::NotFound::VERSION = '1.012';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 
@@ -484,7 +493,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::InvalidConfig;
-$Beam::Wire::Exception::InvalidConfig::VERSION = '1.011';
+$Beam::Wire::Exception::InvalidConfig::VERSION = '1.012';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 use overload q{""} => sub {
@@ -510,7 +519,7 @@ Beam::Wire - Lightweight Dependency Injection Container
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
